@@ -36,9 +36,9 @@ class Environment(object):
 
         # setup builders
         self.builders: Dict[str, Builder] = {}
-        self.add_builders(Environment.DEFAULT_BUILDERS)
+        self.add_builders(*Environment.DEFAULT_BUILDERS)
         if builders is not None:
-            self.add_builders(builders)
+            self.add_builders(*builders)
 
         # add builder default vars
         for builder in self.builders.values():
@@ -133,7 +133,7 @@ class Environment(object):
     #
     # Builders
     #
-    def add_builders(self, builders: Iterable[Builder]):
+    def add_builders(self, *builders):
         for builder in builders:
             for name in Utility.flatten_list(builder.name):
                 self.builders[name] = builder
@@ -148,7 +148,7 @@ class Environment(object):
                 new_inputs.append(input)
         return new_inputs
 
-    def build(self, builder_id, inputs, output=None, deps = None, **kwargs) -> List[Target]:
+    def build(self, builder_id, inputs, output=None, deps=None, **kwargs) -> List[Target]:
         builder = self.builders[builder_id]
         inputs = self.preprocess_inputs(inputs)
         deps = self.preprocess_inputs(deps)
