@@ -1,3 +1,4 @@
+import pathlib
 from typing import Iterable
 
 
@@ -31,8 +32,20 @@ class Utility:
         args = Utility.flatten_list(args)
         s = ''
         for arg in args:
-            if quote_spaces and ' ' in arg:
-                s += f'"{arg}" '
+            sarg = str(arg)
+            if quote_spaces and ' ' in sarg:
+                s += f'"{sarg}" '
             else:
-                s += str(arg) + ' '
-        return s.strip()
\ No newline at end of file
+                s += f'{sarg} '
+
+        return s.strip()
+
+    @staticmethod
+    def path_to_string(path):
+        if path is None:
+            return None
+
+        if isinstance(path, pathlib.Path):
+            return str(path.resolve())
+
+        return str(path)
